WITH pedidos_semana AS (
    SELECT p.id_user, DATE(p.data) AS data_pedido, GROUP_CONCAT(DISTINCT DATE(p.data) ORDER BY p.data ASC) AS datas_pedidos
    FROM pedidos p
    WHERE YEARWEEK(p.data, 1) = YEARWEEK(NOW(), 1) -- Filtra os pedidos da semana atual
    GROUP BY p.id_user
),
usuarios_hoje AS (
    SELECT u.id, u.razao_social, u.dias_pedido, ps.datas_pedidos,
        CASE 
            WHEN ps.datas_pedidos IS NULL THEN 'pendente' 
            WHEN FIND_IN_SET(CURDATE(), ps.datas_pedidos) > 0 THEN 'feito'
            WHEN ps.datas_pedidos IS NOT NULL AND NOT FIND_IN_SET(CURDATE(), ps.datas_pedidos) > 0 THEN 'antecipado'
        END AS status_pedido
    FROM user u
    LEFT JOIN pedidos_semana ps ON u.id = ps.id_user
    WHERE u.status = 'aprovado' 
      AND u.role != 'ADMIN'
      AND u.dias_pedido LIKE CONCAT('%', 
          CASE DAYOFWEEK(NOW())
              WHEN 1 THEN 'Domingo'
              WHEN 2 THEN 'Segunda'
              WHEN 3 THEN 'Terça'
              WHEN 4 THEN 'Quarta'
              WHEN 5 THEN 'Quinta'
              WHEN 6 THEN 'Sexta'
              WHEN 7 THEN 'Sábado'
          END, 
          '%')
)
SELECT * FROM usuarios_hoje;